#include <stdio.h>
#include "fitsio.h"

void printerror( int status)
{
    /*****************************************************/
    /* Print out cfitsio error messages and exit program */
    /*****************************************************/


    if (status)
    {
       fits_report_error(stderr, status); /* print error report */

       exit( status );    /* terminate the program, returning error status */
    }
    return;
}

int fitscopy(char *argv, char *outfile)
{
    fitsfile *infptr, *outfptr;   /* FITS file pointers defined in fitsio.h */
    int status = 0, ii = 1;       /* status must always be initialized = 0  */

    /* Open the input file */
    if ( !fits_open_file(&infptr, argv, READONLY, &status) )
    {
      /* Create the output file */
      if ( !fits_create_file(&outfptr, outfile, &status) )
      {
        /* Copy every HDU until we get an error */
        while( !fits_movabs_hdu(infptr, ii++, NULL, &status) )
          fits_copy_hdu(infptr, outfptr, 0, &status);
 
        /* Reset status after normal error */
        if (status == END_OF_FILE) status = 0;

        fits_close_file(outfptr,  &status);
      }
      fits_close_file(infptr, &status);
    }

    /* if error occured, print out error message */
    if (status) fits_report_error(stderr, status);
    return(status);
}
